drm: msm: Add support AD4 custom event notifications

SDM845 target supports AD4 feature. User-space client of AD4 driver
needs to be notified of system back-light notifications, suspend/resume
events. Change adds support in sde display driver for notify the events.

Change-Id: Ia2fbae75cc66389145292082c46d3bd16653e941
Signed-off-by: Gopikrishnaiah Anandan <agopik@codeaurora.org>
diff --git a/drivers/gpu/drm/msm/msm_drv.h b/drivers/gpu/drm/msm/msm_drv.h
index 322b7f2..7061575 100644
--- a/drivers/gpu/drm/msm/msm_drv.h
+++ b/drivers/gpu/drm/msm/msm_drv.h
@@ -707,13 +707,14 @@
 };
 
 /* *
  * msm_send_crtc_notification - notify user-space clients of crtc events.
  * @crtc: crtc that is generating the event.
  * @event: event that needs to be notified.
  * @payload: payload for the event.
  */
-void msm_send_crtc_notification(struct drm_crtc *crtc,
-		struct drm_event *event, u8 *payload);
+void msm_mode_object_event_nofity(struct drm_mode_object *obj,
+		struct drm_device *dev, struct drm_event *event, u8 *payload);
 #ifdef CONFIG_DRM_MSM_DSI
 void __init msm_dsi_register(void);
 void __exit msm_dsi_unregister(void);
@@ -707,13 +707,14 @@
 
 /* *
- * msm_send_crtc_notification - notify user-space clients of crtc events.
- * @crtc: crtc that is generating the event.
+ * msm_mode_object_event_notify - notify user-space clients of drm object
+ *                                events.
+ * @obj: mode object (crtc/connector) that is generating the event.
  * @event: event that needs to be notified.
  * @payload: payload for the event.